# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['AppGroupArgs', 'AppGroup']

@pulumi.input_type
class AppGroupArgs:
    def __init__(__self__, *,
                 app_name: pulumi.Input[str],
                 group_id: pulumi.Input[str],
                 namespace: pulumi.Input[str],
                 namespace_name: pulumi.Input[str],
                 app_type: Optional[pulumi.Input[int]] = None,
                 app_version: Optional[pulumi.Input[str]] = None,
                 delete_jobs: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_log: Optional[pulumi.Input[bool]] = None,
                 max_concurrency: Optional[pulumi.Input[int]] = None,
                 max_jobs: Optional[pulumi.Input[int]] = None,
                 monitor_config_json: Optional[pulumi.Input[str]] = None,
                 monitor_contacts_json: Optional[pulumi.Input[str]] = None,
                 namespace_source: Optional[pulumi.Input[str]] = None,
                 schedule_busy_workers: Optional[pulumi.Input[bool]] = None):
        """
        The set of arguments for constructing a AppGroup resource.
        :param pulumi.Input[str] app_name: Application Name
        :param pulumi.Input[str] group_id: Application ID
        :param pulumi.Input[str] namespace: The namespace ID, which is obtained on the namespace page of the console.
        :param pulumi.Input[str] namespace_name: The namespace name.
        :param pulumi.Input[int] app_type: Application type.
               - 1, general application.
               - 2, k8s application.
        :param pulumi.Input[str] app_version: Application Version, 1: Basic Edition, 2: Professional Edition
        :param pulumi.Input[bool] delete_jobs: Whether to delete the task in the application Group. The values are as follows:
        :param pulumi.Input[str] description: Application Description
        :param pulumi.Input[bool] enable_log: Whether to enable the log.
               - true: On
               - false: Close
        :param pulumi.Input[int] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[int] max_jobs: Application Grouping Configurable Maximum Number of Tasks
        :param pulumi.Input[str] monitor_config_json: Alarm configuration JSON field. For more information about this field, see **Request Parameters * *.
        :param pulumi.Input[str] monitor_contacts_json: Alarm contact JSON format.
        :param pulumi.Input[str] namespace_source: Not supported for the time being, no need to fill in.
        :param pulumi.Input[bool] schedule_busy_workers: Whether to schedule a busy machine.
        """
        pulumi.set(__self__, "app_name", app_name)
        pulumi.set(__self__, "group_id", group_id)
        pulumi.set(__self__, "namespace", namespace)
        pulumi.set(__self__, "namespace_name", namespace_name)
        if app_type is not None:
            pulumi.set(__self__, "app_type", app_type)
        if app_version is not None:
            pulumi.set(__self__, "app_version", app_version)
        if delete_jobs is not None:
            pulumi.set(__self__, "delete_jobs", delete_jobs)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_log is not None:
            pulumi.set(__self__, "enable_log", enable_log)
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if max_jobs is not None:
            pulumi.set(__self__, "max_jobs", max_jobs)
        if monitor_config_json is not None:
            pulumi.set(__self__, "monitor_config_json", monitor_config_json)
        if monitor_contacts_json is not None:
            pulumi.set(__self__, "monitor_contacts_json", monitor_contacts_json)
        if namespace_source is not None:
            pulumi.set(__self__, "namespace_source", namespace_source)
        if schedule_busy_workers is not None:
            pulumi.set(__self__, "schedule_busy_workers", schedule_busy_workers)

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> pulumi.Input[str]:
        """
        Application Name
        """
        return pulumi.get(self, "app_name")

    @app_name.setter
    def app_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "app_name", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Input[str]:
        """
        Application ID
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Input[str]:
        """
        The namespace ID, which is obtained on the namespace page of the console.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="namespaceName")
    def namespace_name(self) -> pulumi.Input[str]:
        """
        The namespace name.
        """
        return pulumi.get(self, "namespace_name")

    @namespace_name.setter
    def namespace_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "namespace_name", value)

    @property
    @pulumi.getter(name="appType")
    def app_type(self) -> Optional[pulumi.Input[int]]:
        """
        Application type.
        - 1, general application.
        - 2, k8s application.
        """
        return pulumi.get(self, "app_type")

    @app_type.setter
    def app_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "app_type", value)

    @property
    @pulumi.getter(name="appVersion")
    def app_version(self) -> Optional[pulumi.Input[str]]:
        """
        Application Version, 1: Basic Edition, 2: Professional Edition
        """
        return pulumi.get(self, "app_version")

    @app_version.setter
    def app_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_version", value)

    @property
    @pulumi.getter(name="deleteJobs")
    def delete_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to delete the task in the application Group. The values are as follows:
        """
        return pulumi.get(self, "delete_jobs")

    @delete_jobs.setter
    def delete_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_jobs", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Application Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableLog")
    def enable_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable the log.
        - true: On
        - false: Close
        """
        return pulumi.get(self, "enable_log")

    @enable_log.setter
    def enable_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_log", value)

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_concurrency", value)

    @property
    @pulumi.getter(name="maxJobs")
    def max_jobs(self) -> Optional[pulumi.Input[int]]:
        """
        Application Grouping Configurable Maximum Number of Tasks
        """
        return pulumi.get(self, "max_jobs")

    @max_jobs.setter
    def max_jobs(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_jobs", value)

    @property
    @pulumi.getter(name="monitorConfigJson")
    def monitor_config_json(self) -> Optional[pulumi.Input[str]]:
        """
        Alarm configuration JSON field. For more information about this field, see **Request Parameters * *.
        """
        return pulumi.get(self, "monitor_config_json")

    @monitor_config_json.setter
    def monitor_config_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor_config_json", value)

    @property
    @pulumi.getter(name="monitorContactsJson")
    def monitor_contacts_json(self) -> Optional[pulumi.Input[str]]:
        """
        Alarm contact JSON format.
        """
        return pulumi.get(self, "monitor_contacts_json")

    @monitor_contacts_json.setter
    def monitor_contacts_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor_contacts_json", value)

    @property
    @pulumi.getter(name="namespaceSource")
    def namespace_source(self) -> Optional[pulumi.Input[str]]:
        """
        Not supported for the time being, no need to fill in.
        """
        return pulumi.get(self, "namespace_source")

    @namespace_source.setter
    def namespace_source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_source", value)

    @property
    @pulumi.getter(name="scheduleBusyWorkers")
    def schedule_busy_workers(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to schedule a busy machine.
        """
        return pulumi.get(self, "schedule_busy_workers")

    @schedule_busy_workers.setter
    def schedule_busy_workers(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "schedule_busy_workers", value)


@pulumi.input_type
class _AppGroupState:
    def __init__(__self__, *,
                 app_name: Optional[pulumi.Input[str]] = None,
                 app_type: Optional[pulumi.Input[int]] = None,
                 app_version: Optional[pulumi.Input[str]] = None,
                 delete_jobs: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_log: Optional[pulumi.Input[bool]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 max_concurrency: Optional[pulumi.Input[int]] = None,
                 max_jobs: Optional[pulumi.Input[int]] = None,
                 monitor_config_json: Optional[pulumi.Input[str]] = None,
                 monitor_contacts_json: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_name: Optional[pulumi.Input[str]] = None,
                 namespace_source: Optional[pulumi.Input[str]] = None,
                 schedule_busy_workers: Optional[pulumi.Input[bool]] = None):
        """
        Input properties used for looking up and filtering AppGroup resources.
        :param pulumi.Input[str] app_name: Application Name
        :param pulumi.Input[int] app_type: Application type.
               - 1, general application.
               - 2, k8s application.
        :param pulumi.Input[str] app_version: Application Version, 1: Basic Edition, 2: Professional Edition
        :param pulumi.Input[bool] delete_jobs: Whether to delete the task in the application Group. The values are as follows:
        :param pulumi.Input[str] description: Application Description
        :param pulumi.Input[bool] enable_log: Whether to enable the log.
               - true: On
               - false: Close
        :param pulumi.Input[str] group_id: Application ID
        :param pulumi.Input[int] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[int] max_jobs: Application Grouping Configurable Maximum Number of Tasks
        :param pulumi.Input[str] monitor_config_json: Alarm configuration JSON field. For more information about this field, see **Request Parameters * *.
        :param pulumi.Input[str] monitor_contacts_json: Alarm contact JSON format.
        :param pulumi.Input[str] namespace: The namespace ID, which is obtained on the namespace page of the console.
        :param pulumi.Input[str] namespace_name: The namespace name.
        :param pulumi.Input[str] namespace_source: Not supported for the time being, no need to fill in.
        :param pulumi.Input[bool] schedule_busy_workers: Whether to schedule a busy machine.
        """
        if app_name is not None:
            pulumi.set(__self__, "app_name", app_name)
        if app_type is not None:
            pulumi.set(__self__, "app_type", app_type)
        if app_version is not None:
            pulumi.set(__self__, "app_version", app_version)
        if delete_jobs is not None:
            pulumi.set(__self__, "delete_jobs", delete_jobs)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if enable_log is not None:
            pulumi.set(__self__, "enable_log", enable_log)
        if group_id is not None:
            pulumi.set(__self__, "group_id", group_id)
        if max_concurrency is not None:
            pulumi.set(__self__, "max_concurrency", max_concurrency)
        if max_jobs is not None:
            pulumi.set(__self__, "max_jobs", max_jobs)
        if monitor_config_json is not None:
            pulumi.set(__self__, "monitor_config_json", monitor_config_json)
        if monitor_contacts_json is not None:
            pulumi.set(__self__, "monitor_contacts_json", monitor_contacts_json)
        if namespace is not None:
            pulumi.set(__self__, "namespace", namespace)
        if namespace_name is not None:
            pulumi.set(__self__, "namespace_name", namespace_name)
        if namespace_source is not None:
            pulumi.set(__self__, "namespace_source", namespace_source)
        if schedule_busy_workers is not None:
            pulumi.set(__self__, "schedule_busy_workers", schedule_busy_workers)

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> Optional[pulumi.Input[str]]:
        """
        Application Name
        """
        return pulumi.get(self, "app_name")

    @app_name.setter
    def app_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_name", value)

    @property
    @pulumi.getter(name="appType")
    def app_type(self) -> Optional[pulumi.Input[int]]:
        """
        Application type.
        - 1, general application.
        - 2, k8s application.
        """
        return pulumi.get(self, "app_type")

    @app_type.setter
    def app_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "app_type", value)

    @property
    @pulumi.getter(name="appVersion")
    def app_version(self) -> Optional[pulumi.Input[str]]:
        """
        Application Version, 1: Basic Edition, 2: Professional Edition
        """
        return pulumi.get(self, "app_version")

    @app_version.setter
    def app_version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "app_version", value)

    @property
    @pulumi.getter(name="deleteJobs")
    def delete_jobs(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to delete the task in the application Group. The values are as follows:
        """
        return pulumi.get(self, "delete_jobs")

    @delete_jobs.setter
    def delete_jobs(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "delete_jobs", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        Application Description
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="enableLog")
    def enable_log(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to enable the log.
        - true: On
        - false: Close
        """
        return pulumi.get(self, "enable_log")

    @enable_log.setter
    def enable_log(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "enable_log", value)

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> Optional[pulumi.Input[str]]:
        """
        Application ID
        """
        return pulumi.get(self, "group_id")

    @group_id.setter
    def group_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "group_id", value)

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> Optional[pulumi.Input[int]]:
        """
        The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        """
        return pulumi.get(self, "max_concurrency")

    @max_concurrency.setter
    def max_concurrency(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_concurrency", value)

    @property
    @pulumi.getter(name="maxJobs")
    def max_jobs(self) -> Optional[pulumi.Input[int]]:
        """
        Application Grouping Configurable Maximum Number of Tasks
        """
        return pulumi.get(self, "max_jobs")

    @max_jobs.setter
    def max_jobs(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "max_jobs", value)

    @property
    @pulumi.getter(name="monitorConfigJson")
    def monitor_config_json(self) -> Optional[pulumi.Input[str]]:
        """
        Alarm configuration JSON field. For more information about this field, see **Request Parameters * *.
        """
        return pulumi.get(self, "monitor_config_json")

    @monitor_config_json.setter
    def monitor_config_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor_config_json", value)

    @property
    @pulumi.getter(name="monitorContactsJson")
    def monitor_contacts_json(self) -> Optional[pulumi.Input[str]]:
        """
        Alarm contact JSON format.
        """
        return pulumi.get(self, "monitor_contacts_json")

    @monitor_contacts_json.setter
    def monitor_contacts_json(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "monitor_contacts_json", value)

    @property
    @pulumi.getter
    def namespace(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace ID, which is obtained on the namespace page of the console.
        """
        return pulumi.get(self, "namespace")

    @namespace.setter
    def namespace(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace", value)

    @property
    @pulumi.getter(name="namespaceName")
    def namespace_name(self) -> Optional[pulumi.Input[str]]:
        """
        The namespace name.
        """
        return pulumi.get(self, "namespace_name")

    @namespace_name.setter
    def namespace_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_name", value)

    @property
    @pulumi.getter(name="namespaceSource")
    def namespace_source(self) -> Optional[pulumi.Input[str]]:
        """
        Not supported for the time being, no need to fill in.
        """
        return pulumi.get(self, "namespace_source")

    @namespace_source.setter
    def namespace_source(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "namespace_source", value)

    @property
    @pulumi.getter(name="scheduleBusyWorkers")
    def schedule_busy_workers(self) -> Optional[pulumi.Input[bool]]:
        """
        Whether to schedule a busy machine.
        """
        return pulumi.get(self, "schedule_busy_workers")

    @schedule_busy_workers.setter
    def schedule_busy_workers(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "schedule_busy_workers", value)


class AppGroup(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_name: Optional[pulumi.Input[str]] = None,
                 app_type: Optional[pulumi.Input[int]] = None,
                 app_version: Optional[pulumi.Input[str]] = None,
                 delete_jobs: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_log: Optional[pulumi.Input[bool]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 max_concurrency: Optional[pulumi.Input[int]] = None,
                 max_jobs: Optional[pulumi.Input[int]] = None,
                 monitor_config_json: Optional[pulumi.Input[str]] = None,
                 monitor_contacts_json: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_name: Optional[pulumi.Input[str]] = None,
                 namespace_source: Optional[pulumi.Input[str]] = None,
                 schedule_busy_workers: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        """
        Provides a Schedulerx App Group resource.

        For information about Schedulerx App Group and how to use it, see [What is App Group](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        create_name_space = alicloud.schedulerx.Namespace("CreateNameSpace",
            namespace_name=name,
            description=name)
        default = alicloud.schedulerx.AppGroup("default",
            max_jobs=100,
            monitor_contacts_json=json.dumps([
                {
                    "userName": "name1",
                    "userPhone": "89756******",
                },
                {
                    "userName": "name2",
                    "ding": "http://www.example.com",
                },
            ]),
            delete_jobs=False,
            app_type=1,
            namespace_source="schedulerx",
            group_id="example-appgroup-pop-autoexample",
            namespace_name="default",
            description=name,
            monitor_config_json=json.dumps({
                "sendChannel": "sms,ding",
            }),
            app_version="1",
            app_name="example-appgroup-pop-autoexample",
            namespace=create_name_space.namespace_uid,
            enable_log=False,
            schedule_busy_workers=False)
        ```

        ## Import

        Schedulerx App Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:schedulerx/appGroup:AppGroup example <namespace>:<group_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_name: Application Name
        :param pulumi.Input[int] app_type: Application type.
               - 1, general application.
               - 2, k8s application.
        :param pulumi.Input[str] app_version: Application Version, 1: Basic Edition, 2: Professional Edition
        :param pulumi.Input[bool] delete_jobs: Whether to delete the task in the application Group. The values are as follows:
        :param pulumi.Input[str] description: Application Description
        :param pulumi.Input[bool] enable_log: Whether to enable the log.
               - true: On
               - false: Close
        :param pulumi.Input[str] group_id: Application ID
        :param pulumi.Input[int] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[int] max_jobs: Application Grouping Configurable Maximum Number of Tasks
        :param pulumi.Input[str] monitor_config_json: Alarm configuration JSON field. For more information about this field, see **Request Parameters * *.
        :param pulumi.Input[str] monitor_contacts_json: Alarm contact JSON format.
        :param pulumi.Input[str] namespace: The namespace ID, which is obtained on the namespace page of the console.
        :param pulumi.Input[str] namespace_name: The namespace name.
        :param pulumi.Input[str] namespace_source: Not supported for the time being, no need to fill in.
        :param pulumi.Input[bool] schedule_busy_workers: Whether to schedule a busy machine.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: AppGroupArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Schedulerx App Group resource.

        For information about Schedulerx App Group and how to use it, see [What is App Group](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.240.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import json
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        create_name_space = alicloud.schedulerx.Namespace("CreateNameSpace",
            namespace_name=name,
            description=name)
        default = alicloud.schedulerx.AppGroup("default",
            max_jobs=100,
            monitor_contacts_json=json.dumps([
                {
                    "userName": "name1",
                    "userPhone": "89756******",
                },
                {
                    "userName": "name2",
                    "ding": "http://www.example.com",
                },
            ]),
            delete_jobs=False,
            app_type=1,
            namespace_source="schedulerx",
            group_id="example-appgroup-pop-autoexample",
            namespace_name="default",
            description=name,
            monitor_config_json=json.dumps({
                "sendChannel": "sms,ding",
            }),
            app_version="1",
            app_name="example-appgroup-pop-autoexample",
            namespace=create_name_space.namespace_uid,
            enable_log=False,
            schedule_busy_workers=False)
        ```

        ## Import

        Schedulerx App Group can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:schedulerx/appGroup:AppGroup example <namespace>:<group_id>
        ```

        :param str resource_name: The name of the resource.
        :param AppGroupArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(AppGroupArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 app_name: Optional[pulumi.Input[str]] = None,
                 app_type: Optional[pulumi.Input[int]] = None,
                 app_version: Optional[pulumi.Input[str]] = None,
                 delete_jobs: Optional[pulumi.Input[bool]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 enable_log: Optional[pulumi.Input[bool]] = None,
                 group_id: Optional[pulumi.Input[str]] = None,
                 max_concurrency: Optional[pulumi.Input[int]] = None,
                 max_jobs: Optional[pulumi.Input[int]] = None,
                 monitor_config_json: Optional[pulumi.Input[str]] = None,
                 monitor_contacts_json: Optional[pulumi.Input[str]] = None,
                 namespace: Optional[pulumi.Input[str]] = None,
                 namespace_name: Optional[pulumi.Input[str]] = None,
                 namespace_source: Optional[pulumi.Input[str]] = None,
                 schedule_busy_workers: Optional[pulumi.Input[bool]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = AppGroupArgs.__new__(AppGroupArgs)

            if app_name is None and not opts.urn:
                raise TypeError("Missing required property 'app_name'")
            __props__.__dict__["app_name"] = app_name
            __props__.__dict__["app_type"] = app_type
            __props__.__dict__["app_version"] = app_version
            __props__.__dict__["delete_jobs"] = delete_jobs
            __props__.__dict__["description"] = description
            __props__.__dict__["enable_log"] = enable_log
            if group_id is None and not opts.urn:
                raise TypeError("Missing required property 'group_id'")
            __props__.__dict__["group_id"] = group_id
            __props__.__dict__["max_concurrency"] = max_concurrency
            __props__.__dict__["max_jobs"] = max_jobs
            __props__.__dict__["monitor_config_json"] = monitor_config_json
            __props__.__dict__["monitor_contacts_json"] = monitor_contacts_json
            if namespace is None and not opts.urn:
                raise TypeError("Missing required property 'namespace'")
            __props__.__dict__["namespace"] = namespace
            if namespace_name is None and not opts.urn:
                raise TypeError("Missing required property 'namespace_name'")
            __props__.__dict__["namespace_name"] = namespace_name
            __props__.__dict__["namespace_source"] = namespace_source
            __props__.__dict__["schedule_busy_workers"] = schedule_busy_workers
        super(AppGroup, __self__).__init__(
            'alicloud:schedulerx/appGroup:AppGroup',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            app_name: Optional[pulumi.Input[str]] = None,
            app_type: Optional[pulumi.Input[int]] = None,
            app_version: Optional[pulumi.Input[str]] = None,
            delete_jobs: Optional[pulumi.Input[bool]] = None,
            description: Optional[pulumi.Input[str]] = None,
            enable_log: Optional[pulumi.Input[bool]] = None,
            group_id: Optional[pulumi.Input[str]] = None,
            max_concurrency: Optional[pulumi.Input[int]] = None,
            max_jobs: Optional[pulumi.Input[int]] = None,
            monitor_config_json: Optional[pulumi.Input[str]] = None,
            monitor_contacts_json: Optional[pulumi.Input[str]] = None,
            namespace: Optional[pulumi.Input[str]] = None,
            namespace_name: Optional[pulumi.Input[str]] = None,
            namespace_source: Optional[pulumi.Input[str]] = None,
            schedule_busy_workers: Optional[pulumi.Input[bool]] = None) -> 'AppGroup':
        """
        Get an existing AppGroup resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] app_name: Application Name
        :param pulumi.Input[int] app_type: Application type.
               - 1, general application.
               - 2, k8s application.
        :param pulumi.Input[str] app_version: Application Version, 1: Basic Edition, 2: Professional Edition
        :param pulumi.Input[bool] delete_jobs: Whether to delete the task in the application Group. The values are as follows:
        :param pulumi.Input[str] description: Application Description
        :param pulumi.Input[bool] enable_log: Whether to enable the log.
               - true: On
               - false: Close
        :param pulumi.Input[str] group_id: Application ID
        :param pulumi.Input[int] max_concurrency: The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        :param pulumi.Input[int] max_jobs: Application Grouping Configurable Maximum Number of Tasks
        :param pulumi.Input[str] monitor_config_json: Alarm configuration JSON field. For more information about this field, see **Request Parameters * *.
        :param pulumi.Input[str] monitor_contacts_json: Alarm contact JSON format.
        :param pulumi.Input[str] namespace: The namespace ID, which is obtained on the namespace page of the console.
        :param pulumi.Input[str] namespace_name: The namespace name.
        :param pulumi.Input[str] namespace_source: Not supported for the time being, no need to fill in.
        :param pulumi.Input[bool] schedule_busy_workers: Whether to schedule a busy machine.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _AppGroupState.__new__(_AppGroupState)

        __props__.__dict__["app_name"] = app_name
        __props__.__dict__["app_type"] = app_type
        __props__.__dict__["app_version"] = app_version
        __props__.__dict__["delete_jobs"] = delete_jobs
        __props__.__dict__["description"] = description
        __props__.__dict__["enable_log"] = enable_log
        __props__.__dict__["group_id"] = group_id
        __props__.__dict__["max_concurrency"] = max_concurrency
        __props__.__dict__["max_jobs"] = max_jobs
        __props__.__dict__["monitor_config_json"] = monitor_config_json
        __props__.__dict__["monitor_contacts_json"] = monitor_contacts_json
        __props__.__dict__["namespace"] = namespace
        __props__.__dict__["namespace_name"] = namespace_name
        __props__.__dict__["namespace_source"] = namespace_source
        __props__.__dict__["schedule_busy_workers"] = schedule_busy_workers
        return AppGroup(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="appName")
    def app_name(self) -> pulumi.Output[str]:
        """
        Application Name
        """
        return pulumi.get(self, "app_name")

    @property
    @pulumi.getter(name="appType")
    def app_type(self) -> pulumi.Output[Optional[int]]:
        """
        Application type.
        - 1, general application.
        - 2, k8s application.
        """
        return pulumi.get(self, "app_type")

    @property
    @pulumi.getter(name="appVersion")
    def app_version(self) -> pulumi.Output[Optional[str]]:
        """
        Application Version, 1: Basic Edition, 2: Professional Edition
        """
        return pulumi.get(self, "app_version")

    @property
    @pulumi.getter(name="deleteJobs")
    def delete_jobs(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to delete the task in the application Group. The values are as follows:
        """
        return pulumi.get(self, "delete_jobs")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        Application Description
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="enableLog")
    def enable_log(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to enable the log.
        - true: On
        - false: Close
        """
        return pulumi.get(self, "enable_log")

    @property
    @pulumi.getter(name="groupId")
    def group_id(self) -> pulumi.Output[str]:
        """
        Application ID
        """
        return pulumi.get(self, "group_id")

    @property
    @pulumi.getter(name="maxConcurrency")
    def max_concurrency(self) -> pulumi.Output[Optional[int]]:
        """
        The maximum number of instances running at the same time. The default value is 1, that is, the last trigger is not completed, and the next trigger will not be performed even at the running time.
        """
        return pulumi.get(self, "max_concurrency")

    @property
    @pulumi.getter(name="maxJobs")
    def max_jobs(self) -> pulumi.Output[Optional[int]]:
        """
        Application Grouping Configurable Maximum Number of Tasks
        """
        return pulumi.get(self, "max_jobs")

    @property
    @pulumi.getter(name="monitorConfigJson")
    def monitor_config_json(self) -> pulumi.Output[Optional[str]]:
        """
        Alarm configuration JSON field. For more information about this field, see **Request Parameters * *.
        """
        return pulumi.get(self, "monitor_config_json")

    @property
    @pulumi.getter(name="monitorContactsJson")
    def monitor_contacts_json(self) -> pulumi.Output[Optional[str]]:
        """
        Alarm contact JSON format.
        """
        return pulumi.get(self, "monitor_contacts_json")

    @property
    @pulumi.getter
    def namespace(self) -> pulumi.Output[str]:
        """
        The namespace ID, which is obtained on the namespace page of the console.
        """
        return pulumi.get(self, "namespace")

    @property
    @pulumi.getter(name="namespaceName")
    def namespace_name(self) -> pulumi.Output[str]:
        """
        The namespace name.
        """
        return pulumi.get(self, "namespace_name")

    @property
    @pulumi.getter(name="namespaceSource")
    def namespace_source(self) -> pulumi.Output[Optional[str]]:
        """
        Not supported for the time being, no need to fill in.
        """
        return pulumi.get(self, "namespace_source")

    @property
    @pulumi.getter(name="scheduleBusyWorkers")
    def schedule_busy_workers(self) -> pulumi.Output[Optional[bool]]:
        """
        Whether to schedule a busy machine.
        """
        return pulumi.get(self, "schedule_busy_workers")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs
from ._inputs import *

__all__ = ['FirewallVpcFirewallArgs', 'FirewallVpcFirewall']

@pulumi.input_type
class FirewallVpcFirewallArgs:
    def __init__(__self__, *,
                 local_vpc: pulumi.Input['FirewallVpcFirewallLocalVpcArgs'],
                 peer_vpc: pulumi.Input['FirewallVpcFirewallPeerVpcArgs'],
                 status: pulumi.Input[str],
                 vpc_firewall_name: pulumi.Input[str],
                 lang: Optional[pulumi.Input[str]] = None,
                 member_uid: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a FirewallVpcFirewall resource.
        :param pulumi.Input['FirewallVpcFirewallLocalVpcArgs'] local_vpc: The details of the local VPC. See `local_vpc` below.
        :param pulumi.Input['FirewallVpcFirewallPeerVpcArgs'] peer_vpc: The details of the peer VPC. See `peer_vpc` below.
        :param pulumi.Input[str] status: The status of the resource. Valid values:
        :param pulumi.Input[str] vpc_firewall_name: The name of the VPC firewall instance.
        :param pulumi.Input[str] lang: The language type of the requested and received messages. Valid values:
        :param pulumi.Input[str] member_uid: The UID of the Alibaba Cloud member account.
        """
        pulumi.set(__self__, "local_vpc", local_vpc)
        pulumi.set(__self__, "peer_vpc", peer_vpc)
        pulumi.set(__self__, "status", status)
        pulumi.set(__self__, "vpc_firewall_name", vpc_firewall_name)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if member_uid is not None:
            pulumi.set(__self__, "member_uid", member_uid)

    @property
    @pulumi.getter(name="localVpc")
    def local_vpc(self) -> pulumi.Input['FirewallVpcFirewallLocalVpcArgs']:
        """
        The details of the local VPC. See `local_vpc` below.
        """
        return pulumi.get(self, "local_vpc")

    @local_vpc.setter
    def local_vpc(self, value: pulumi.Input['FirewallVpcFirewallLocalVpcArgs']):
        pulumi.set(self, "local_vpc", value)

    @property
    @pulumi.getter(name="peerVpc")
    def peer_vpc(self) -> pulumi.Input['FirewallVpcFirewallPeerVpcArgs']:
        """
        The details of the peer VPC. See `peer_vpc` below.
        """
        return pulumi.get(self, "peer_vpc")

    @peer_vpc.setter
    def peer_vpc(self, value: pulumi.Input['FirewallVpcFirewallPeerVpcArgs']):
        pulumi.set(self, "peer_vpc", value)

    @property
    @pulumi.getter
    def status(self) -> pulumi.Input[str]:
        """
        The status of the resource. Valid values:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: pulumi.Input[str]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcFirewallName")
    def vpc_firewall_name(self) -> pulumi.Input[str]:
        """
        The name of the VPC firewall instance.
        """
        return pulumi.get(self, "vpc_firewall_name")

    @vpc_firewall_name.setter
    def vpc_firewall_name(self, value: pulumi.Input[str]):
        pulumi.set(self, "vpc_firewall_name", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        The language type of the requested and received messages. Valid values:
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The UID of the Alibaba Cloud member account.
        """
        return pulumi.get(self, "member_uid")

    @member_uid.setter
    def member_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_uid", value)


@pulumi.input_type
class _FirewallVpcFirewallState:
    def __init__(__self__, *,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 connect_type: Optional[pulumi.Input[str]] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 local_vpc: Optional[pulumi.Input['FirewallVpcFirewallLocalVpcArgs']] = None,
                 member_uid: Optional[pulumi.Input[str]] = None,
                 peer_vpc: Optional[pulumi.Input['FirewallVpcFirewallPeerVpcArgs']] = None,
                 region_status: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_firewall_id: Optional[pulumi.Input[str]] = None,
                 vpc_firewall_name: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering FirewallVpcFirewall resources.
        :param pulumi.Input[int] bandwidth: Bandwidth specifications for high-speed channels. Unit: Mbps.
        :param pulumi.Input[str] connect_type: The communication type of the VPC firewall.
        :param pulumi.Input[str] lang: The language type of the requested and received messages. Valid values:
        :param pulumi.Input['FirewallVpcFirewallLocalVpcArgs'] local_vpc: The details of the local VPC. See `local_vpc` below.
        :param pulumi.Input[str] member_uid: The UID of the Alibaba Cloud member account.
        :param pulumi.Input['FirewallVpcFirewallPeerVpcArgs'] peer_vpc: The details of the peer VPC. See `peer_vpc` below.
        :param pulumi.Input[str] region_status: The region is open.
        :param pulumi.Input[str] status: The status of the resource. Valid values:
        :param pulumi.Input[str] vpc_firewall_id: The ID of the VPC firewall instance.
        :param pulumi.Input[str] vpc_firewall_name: The name of the VPC firewall instance.
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if connect_type is not None:
            pulumi.set(__self__, "connect_type", connect_type)
        if lang is not None:
            pulumi.set(__self__, "lang", lang)
        if local_vpc is not None:
            pulumi.set(__self__, "local_vpc", local_vpc)
        if member_uid is not None:
            pulumi.set(__self__, "member_uid", member_uid)
        if peer_vpc is not None:
            pulumi.set(__self__, "peer_vpc", peer_vpc)
        if region_status is not None:
            pulumi.set(__self__, "region_status", region_status)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if vpc_firewall_id is not None:
            pulumi.set(__self__, "vpc_firewall_id", vpc_firewall_id)
        if vpc_firewall_name is not None:
            pulumi.set(__self__, "vpc_firewall_name", vpc_firewall_name)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        Bandwidth specifications for high-speed channels. Unit: Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="connectType")
    def connect_type(self) -> Optional[pulumi.Input[str]]:
        """
        The communication type of the VPC firewall.
        """
        return pulumi.get(self, "connect_type")

    @connect_type.setter
    def connect_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "connect_type", value)

    @property
    @pulumi.getter
    def lang(self) -> Optional[pulumi.Input[str]]:
        """
        The language type of the requested and received messages. Valid values:
        """
        return pulumi.get(self, "lang")

    @lang.setter
    def lang(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "lang", value)

    @property
    @pulumi.getter(name="localVpc")
    def local_vpc(self) -> Optional[pulumi.Input['FirewallVpcFirewallLocalVpcArgs']]:
        """
        The details of the local VPC. See `local_vpc` below.
        """
        return pulumi.get(self, "local_vpc")

    @local_vpc.setter
    def local_vpc(self, value: Optional[pulumi.Input['FirewallVpcFirewallLocalVpcArgs']]):
        pulumi.set(self, "local_vpc", value)

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> Optional[pulumi.Input[str]]:
        """
        The UID of the Alibaba Cloud member account.
        """
        return pulumi.get(self, "member_uid")

    @member_uid.setter
    def member_uid(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "member_uid", value)

    @property
    @pulumi.getter(name="peerVpc")
    def peer_vpc(self) -> Optional[pulumi.Input['FirewallVpcFirewallPeerVpcArgs']]:
        """
        The details of the peer VPC. See `peer_vpc` below.
        """
        return pulumi.get(self, "peer_vpc")

    @peer_vpc.setter
    def peer_vpc(self, value: Optional[pulumi.Input['FirewallVpcFirewallPeerVpcArgs']]):
        pulumi.set(self, "peer_vpc", value)

    @property
    @pulumi.getter(name="regionStatus")
    def region_status(self) -> Optional[pulumi.Input[str]]:
        """
        The region is open.
        """
        return pulumi.get(self, "region_status")

    @region_status.setter
    def region_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region_status", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource. Valid values:
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="vpcFirewallId")
    def vpc_firewall_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the VPC firewall instance.
        """
        return pulumi.get(self, "vpc_firewall_id")

    @vpc_firewall_id.setter
    def vpc_firewall_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_firewall_id", value)

    @property
    @pulumi.getter(name="vpcFirewallName")
    def vpc_firewall_name(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the VPC firewall instance.
        """
        return pulumi.get(self, "vpc_firewall_name")

    @vpc_firewall_name.setter
    def vpc_firewall_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vpc_firewall_name", value)


class FirewallVpcFirewall(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 local_vpc: Optional[pulumi.Input[Union['FirewallVpcFirewallLocalVpcArgs', 'FirewallVpcFirewallLocalVpcArgsDict']]] = None,
                 member_uid: Optional[pulumi.Input[str]] = None,
                 peer_vpc: Optional[pulumi.Input[Union['FirewallVpcFirewallPeerVpcArgs', 'FirewallVpcFirewallPeerVpcArgsDict']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_firewall_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Cloud Firewall Vpc Firewall resource.

        For information about Cloud Firewall Vpc Firewall and how to use it, see [What is Vpc Firewall](https://www.alibabacloud.com/help/en/cloud-firewall/developer-reference/api-cloudfw-2017-12-07-createvpcfirewallconfigure).

        > **NOTE:** Available since v1.194.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        current = alicloud.get_account()
        default = alicloud.cloudfirewall.FirewallVpcFirewall("default",
            vpc_firewall_name="tf-example",
            member_uid=current.id,
            local_vpc={
                "vpc_id": "vpc-bp1d065m6hzn1xbw8ibfd",
                "region_no": "cn-hangzhou",
                "local_vpc_cidr_table_lists": [{
                    "local_route_table_id": "vtb-bp1lj0ddg846856chpzrv",
                    "local_route_entry_lists": [{
                        "local_next_hop_instance_id": "ri-bp1uobww3aputjlwwkyrh",
                        "local_destination_cidr": "10.1.0.0/16",
                    }],
                }],
            },
            peer_vpc={
                "vpc_id": "vpc-bp1gcmm64o3caox84v0nz",
                "region_no": "cn-hangzhou",
                "peer_vpc_cidr_table_lists": [{
                    "peer_route_table_id": "vtb-bp1f516f2hh4sok1ig9b5",
                    "peer_route_entry_lists": [{
                        "peer_destination_cidr": "10.0.0.0/16",
                        "peer_next_hop_instance_id": "ri-bp1thhtgf6ydr2or52l3n",
                    }],
                }],
            },
            status="open")
        ```

        ## Import

        Cloud Firewall Vpc Firewall can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/firewallVpcFirewall:FirewallVpcFirewall example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] lang: The language type of the requested and received messages. Valid values:
        :param pulumi.Input[Union['FirewallVpcFirewallLocalVpcArgs', 'FirewallVpcFirewallLocalVpcArgsDict']] local_vpc: The details of the local VPC. See `local_vpc` below.
        :param pulumi.Input[str] member_uid: The UID of the Alibaba Cloud member account.
        :param pulumi.Input[Union['FirewallVpcFirewallPeerVpcArgs', 'FirewallVpcFirewallPeerVpcArgsDict']] peer_vpc: The details of the peer VPC. See `peer_vpc` below.
        :param pulumi.Input[str] status: The status of the resource. Valid values:
        :param pulumi.Input[str] vpc_firewall_name: The name of the VPC firewall instance.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: FirewallVpcFirewallArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Cloud Firewall Vpc Firewall resource.

        For information about Cloud Firewall Vpc Firewall and how to use it, see [What is Vpc Firewall](https://www.alibabacloud.com/help/en/cloud-firewall/developer-reference/api-cloudfw-2017-12-07-createvpcfirewallconfigure).

        > **NOTE:** Available since v1.194.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        current = alicloud.get_account()
        default = alicloud.cloudfirewall.FirewallVpcFirewall("default",
            vpc_firewall_name="tf-example",
            member_uid=current.id,
            local_vpc={
                "vpc_id": "vpc-bp1d065m6hzn1xbw8ibfd",
                "region_no": "cn-hangzhou",
                "local_vpc_cidr_table_lists": [{
                    "local_route_table_id": "vtb-bp1lj0ddg846856chpzrv",
                    "local_route_entry_lists": [{
                        "local_next_hop_instance_id": "ri-bp1uobww3aputjlwwkyrh",
                        "local_destination_cidr": "10.1.0.0/16",
                    }],
                }],
            },
            peer_vpc={
                "vpc_id": "vpc-bp1gcmm64o3caox84v0nz",
                "region_no": "cn-hangzhou",
                "peer_vpc_cidr_table_lists": [{
                    "peer_route_table_id": "vtb-bp1f516f2hh4sok1ig9b5",
                    "peer_route_entry_lists": [{
                        "peer_destination_cidr": "10.0.0.0/16",
                        "peer_next_hop_instance_id": "ri-bp1thhtgf6ydr2or52l3n",
                    }],
                }],
            },
            status="open")
        ```

        ## Import

        Cloud Firewall Vpc Firewall can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:cloudfirewall/firewallVpcFirewall:FirewallVpcFirewall example <id>
        ```

        :param str resource_name: The name of the resource.
        :param FirewallVpcFirewallArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(FirewallVpcFirewallArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 lang: Optional[pulumi.Input[str]] = None,
                 local_vpc: Optional[pulumi.Input[Union['FirewallVpcFirewallLocalVpcArgs', 'FirewallVpcFirewallLocalVpcArgsDict']]] = None,
                 member_uid: Optional[pulumi.Input[str]] = None,
                 peer_vpc: Optional[pulumi.Input[Union['FirewallVpcFirewallPeerVpcArgs', 'FirewallVpcFirewallPeerVpcArgsDict']]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 vpc_firewall_name: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = FirewallVpcFirewallArgs.__new__(FirewallVpcFirewallArgs)

            __props__.__dict__["lang"] = lang
            if local_vpc is None and not opts.urn:
                raise TypeError("Missing required property 'local_vpc'")
            __props__.__dict__["local_vpc"] = local_vpc
            __props__.__dict__["member_uid"] = member_uid
            if peer_vpc is None and not opts.urn:
                raise TypeError("Missing required property 'peer_vpc'")
            __props__.__dict__["peer_vpc"] = peer_vpc
            if status is None and not opts.urn:
                raise TypeError("Missing required property 'status'")
            __props__.__dict__["status"] = status
            if vpc_firewall_name is None and not opts.urn:
                raise TypeError("Missing required property 'vpc_firewall_name'")
            __props__.__dict__["vpc_firewall_name"] = vpc_firewall_name
            __props__.__dict__["bandwidth"] = None
            __props__.__dict__["connect_type"] = None
            __props__.__dict__["region_status"] = None
            __props__.__dict__["vpc_firewall_id"] = None
        super(FirewallVpcFirewall, __self__).__init__(
            'alicloud:cloudfirewall/firewallVpcFirewall:FirewallVpcFirewall',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth: Optional[pulumi.Input[int]] = None,
            connect_type: Optional[pulumi.Input[str]] = None,
            lang: Optional[pulumi.Input[str]] = None,
            local_vpc: Optional[pulumi.Input[Union['FirewallVpcFirewallLocalVpcArgs', 'FirewallVpcFirewallLocalVpcArgsDict']]] = None,
            member_uid: Optional[pulumi.Input[str]] = None,
            peer_vpc: Optional[pulumi.Input[Union['FirewallVpcFirewallPeerVpcArgs', 'FirewallVpcFirewallPeerVpcArgsDict']]] = None,
            region_status: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            vpc_firewall_id: Optional[pulumi.Input[str]] = None,
            vpc_firewall_name: Optional[pulumi.Input[str]] = None) -> 'FirewallVpcFirewall':
        """
        Get an existing FirewallVpcFirewall resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: Bandwidth specifications for high-speed channels. Unit: Mbps.
        :param pulumi.Input[str] connect_type: The communication type of the VPC firewall.
        :param pulumi.Input[str] lang: The language type of the requested and received messages. Valid values:
        :param pulumi.Input[Union['FirewallVpcFirewallLocalVpcArgs', 'FirewallVpcFirewallLocalVpcArgsDict']] local_vpc: The details of the local VPC. See `local_vpc` below.
        :param pulumi.Input[str] member_uid: The UID of the Alibaba Cloud member account.
        :param pulumi.Input[Union['FirewallVpcFirewallPeerVpcArgs', 'FirewallVpcFirewallPeerVpcArgsDict']] peer_vpc: The details of the peer VPC. See `peer_vpc` below.
        :param pulumi.Input[str] region_status: The region is open.
        :param pulumi.Input[str] status: The status of the resource. Valid values:
        :param pulumi.Input[str] vpc_firewall_id: The ID of the VPC firewall instance.
        :param pulumi.Input[str] vpc_firewall_name: The name of the VPC firewall instance.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _FirewallVpcFirewallState.__new__(_FirewallVpcFirewallState)

        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["connect_type"] = connect_type
        __props__.__dict__["lang"] = lang
        __props__.__dict__["local_vpc"] = local_vpc
        __props__.__dict__["member_uid"] = member_uid
        __props__.__dict__["peer_vpc"] = peer_vpc
        __props__.__dict__["region_status"] = region_status
        __props__.__dict__["status"] = status
        __props__.__dict__["vpc_firewall_id"] = vpc_firewall_id
        __props__.__dict__["vpc_firewall_name"] = vpc_firewall_name
        return FirewallVpcFirewall(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[int]:
        """
        Bandwidth specifications for high-speed channels. Unit: Mbps.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="connectType")
    def connect_type(self) -> pulumi.Output[str]:
        """
        The communication type of the VPC firewall.
        """
        return pulumi.get(self, "connect_type")

    @property
    @pulumi.getter
    def lang(self) -> pulumi.Output[Optional[str]]:
        """
        The language type of the requested and received messages. Valid values:
        """
        return pulumi.get(self, "lang")

    @property
    @pulumi.getter(name="localVpc")
    def local_vpc(self) -> pulumi.Output['outputs.FirewallVpcFirewallLocalVpc']:
        """
        The details of the local VPC. See `local_vpc` below.
        """
        return pulumi.get(self, "local_vpc")

    @property
    @pulumi.getter(name="memberUid")
    def member_uid(self) -> pulumi.Output[Optional[str]]:
        """
        The UID of the Alibaba Cloud member account.
        """
        return pulumi.get(self, "member_uid")

    @property
    @pulumi.getter(name="peerVpc")
    def peer_vpc(self) -> pulumi.Output['outputs.FirewallVpcFirewallPeerVpc']:
        """
        The details of the peer VPC. See `peer_vpc` below.
        """
        return pulumi.get(self, "peer_vpc")

    @property
    @pulumi.getter(name="regionStatus")
    def region_status(self) -> pulumi.Output[str]:
        """
        The region is open.
        """
        return pulumi.get(self, "region_status")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource. Valid values:
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="vpcFirewallId")
    def vpc_firewall_id(self) -> pulumi.Output[str]:
        """
        The ID of the VPC firewall instance.
        """
        return pulumi.get(self, "vpc_firewall_id")

    @property
    @pulumi.getter(name="vpcFirewallName")
    def vpc_firewall_name(self) -> pulumi.Output[str]:
        """
        The name of the VPC firewall instance.
        """
        return pulumi.get(self, "vpc_firewall_name")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from . import _utilities
from . import outputs

__all__ = [
    'GetRegionsResult',
    'AwaitableGetRegionsResult',
    'get_regions',
    'get_regions_output',
]

@pulumi.output_type
class GetRegionsResult:
    """
    A collection of values returned by getRegions.
    """
    def __init__(__self__, current=None, id=None, ids=None, name=None, output_file=None, regions=None):
        if current and not isinstance(current, bool):
            raise TypeError("Expected argument 'current' to be a bool")
        pulumi.set(__self__, "current", current)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if name and not isinstance(name, str):
            raise TypeError("Expected argument 'name' to be a str")
        pulumi.set(__self__, "name", name)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if regions and not isinstance(regions, list):
            raise TypeError("Expected argument 'regions' to be a list")
        pulumi.set(__self__, "regions", regions)

    @property
    @pulumi.getter
    def current(self) -> bool:
        return pulumi.get(self, "current")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of region IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter
    def name(self) -> str:
        return pulumi.get(self, "name")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter
    def regions(self) -> Sequence['outputs.GetRegionsRegionResult']:
        """
        A list of regions. Each element contains the following attributes:
        """
        return pulumi.get(self, "regions")


class AwaitableGetRegionsResult(GetRegionsResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetRegionsResult(
            current=self.current,
            id=self.id,
            ids=self.ids,
            name=self.name,
            output_file=self.output_file,
            regions=self.regions)


def get_regions(current: Optional[bool] = None,
                name: Optional[str] = None,
                output_file: Optional[str] = None,
                opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetRegionsResult:
    """
    This data source provides Alibaba Cloud regions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    current_region_ds = alicloud.get_regions(current=True)
    pulumi.export("currentRegionId", current_region_ds.regions[0].id)
    ```


    :param bool current: Set to true to match only the region configured in the provider.
    :param str name: The name of the region to select, such as `eu-central-1`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
           
           > **NOTE:** You will get an error if you set `current` to true and `name` to a different value from the one you configured in the provider.
           It is better to either use `name` or `current`, but not both at the same time.
    """
    __args__ = dict()
    __args__['current'] = current
    __args__['name'] = name
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:index/getRegions:getRegions', __args__, opts=opts, typ=GetRegionsResult).value

    return AwaitableGetRegionsResult(
        current=pulumi.get(__ret__, 'current'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        name=pulumi.get(__ret__, 'name'),
        output_file=pulumi.get(__ret__, 'output_file'),
        regions=pulumi.get(__ret__, 'regions'))
def get_regions_output(current: Optional[pulumi.Input[Optional[bool]]] = None,
                       name: Optional[pulumi.Input[Optional[str]]] = None,
                       output_file: Optional[pulumi.Input[Optional[str]]] = None,
                       opts: Optional[Union[pulumi.InvokeOptions, pulumi.InvokeOutputOptions]] = None) -> pulumi.Output[GetRegionsResult]:
    """
    This data source provides Alibaba Cloud regions.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    current_region_ds = alicloud.get_regions(current=True)
    pulumi.export("currentRegionId", current_region_ds.regions[0].id)
    ```


    :param bool current: Set to true to match only the region configured in the provider.
    :param str name: The name of the region to select, such as `eu-central-1`.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
           
           > **NOTE:** You will get an error if you set `current` to true and `name` to a different value from the one you configured in the provider.
           It is better to either use `name` or `current`, but not both at the same time.
    """
    __args__ = dict()
    __args__['current'] = current
    __args__['name'] = name
    __args__['outputFile'] = output_file
    opts = pulumi.InvokeOutputOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:index/getRegions:getRegions', __args__, opts=opts, typ=GetRegionsResult)
    return __ret__.apply(lambda __response__: GetRegionsResult(
        current=pulumi.get(__response__, 'current'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        name=pulumi.get(__response__, 'name'),
        output_file=pulumi.get(__response__, 'output_file'),
        regions=pulumi.get(__response__, 'regions')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['LoadBalancerAccessLogConfigAttachmentArgs', 'LoadBalancerAccessLogConfigAttachment']

@pulumi.input_type
class LoadBalancerAccessLogConfigAttachmentArgs:
    def __init__(__self__, *,
                 load_balancer_id: pulumi.Input[str],
                 log_project: pulumi.Input[str],
                 log_store: pulumi.Input[str]):
        """
        The set of arguments for constructing a LoadBalancerAccessLogConfigAttachment resource.
        :param pulumi.Input[str] load_balancer_id: The ID of the load balancing instance.
        :param pulumi.Input[str] log_project: The log items shipped by the access log.
        :param pulumi.Input[str] log_store: Logstore for log delivery.
        """
        pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        pulumi.set(__self__, "log_project", log_project)
        pulumi.set(__self__, "log_store", log_store)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Input[str]:
        """
        The ID of the load balancing instance.
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="logProject")
    def log_project(self) -> pulumi.Input[str]:
        """
        The log items shipped by the access log.
        """
        return pulumi.get(self, "log_project")

    @log_project.setter
    def log_project(self, value: pulumi.Input[str]):
        pulumi.set(self, "log_project", value)

    @property
    @pulumi.getter(name="logStore")
    def log_store(self) -> pulumi.Input[str]:
        """
        Logstore for log delivery.
        """
        return pulumi.get(self, "log_store")

    @log_store.setter
    def log_store(self, value: pulumi.Input[str]):
        pulumi.set(self, "log_store", value)


@pulumi.input_type
class _LoadBalancerAccessLogConfigAttachmentState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[str]] = None,
                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                 log_project: Optional[pulumi.Input[str]] = None,
                 log_store: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering LoadBalancerAccessLogConfigAttachment resources.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] load_balancer_id: The ID of the load balancing instance.
        :param pulumi.Input[str] log_project: The log items shipped by the access log.
        :param pulumi.Input[str] log_store: Logstore for log delivery.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if load_balancer_id is not None:
            pulumi.set(__self__, "load_balancer_id", load_balancer_id)
        if log_project is not None:
            pulumi.set(__self__, "log_project", log_project)
        if log_store is not None:
            pulumi.set(__self__, "log_store", log_store)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> Optional[pulumi.Input[str]]:
        """
        The ID of the load balancing instance.
        """
        return pulumi.get(self, "load_balancer_id")

    @load_balancer_id.setter
    def load_balancer_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "load_balancer_id", value)

    @property
    @pulumi.getter(name="logProject")
    def log_project(self) -> Optional[pulumi.Input[str]]:
        """
        The log items shipped by the access log.
        """
        return pulumi.get(self, "log_project")

    @log_project.setter
    def log_project(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_project", value)

    @property
    @pulumi.getter(name="logStore")
    def log_store(self) -> Optional[pulumi.Input[str]]:
        """
        Logstore for log delivery.
        """
        return pulumi.get(self, "log_store")

    @log_store.setter
    def log_store(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "log_store", value)


class LoadBalancerAccessLogConfigAttachment(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                 log_project: Optional[pulumi.Input[str]] = None,
                 log_store: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a Application Load Balancer (ALB) Load Balancer Access Log Config Attachment resource.

        Attachment between ALB and AccessLog.

        For information about Application Load Balancer (ALB) Load Balancer Access Log Config Attachment and how to use it, see [What is Load Balancer Access Log Config Attachment](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.241.0.

        ## Import

        Application Load Balancer (ALB) Load Balancer Access Log Config Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:alb/loadBalancerAccessLogConfigAttachment:LoadBalancerAccessLogConfigAttachment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] load_balancer_id: The ID of the load balancing instance.
        :param pulumi.Input[str] log_project: The log items shipped by the access log.
        :param pulumi.Input[str] log_store: Logstore for log delivery.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: LoadBalancerAccessLogConfigAttachmentArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Application Load Balancer (ALB) Load Balancer Access Log Config Attachment resource.

        Attachment between ALB and AccessLog.

        For information about Application Load Balancer (ALB) Load Balancer Access Log Config Attachment and how to use it, see [What is Load Balancer Access Log Config Attachment](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.241.0.

        ## Import

        Application Load Balancer (ALB) Load Balancer Access Log Config Attachment can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:alb/loadBalancerAccessLogConfigAttachment:LoadBalancerAccessLogConfigAttachment example <id>
        ```

        :param str resource_name: The name of the resource.
        :param LoadBalancerAccessLogConfigAttachmentArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(LoadBalancerAccessLogConfigAttachmentArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 load_balancer_id: Optional[pulumi.Input[str]] = None,
                 log_project: Optional[pulumi.Input[str]] = None,
                 log_store: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = LoadBalancerAccessLogConfigAttachmentArgs.__new__(LoadBalancerAccessLogConfigAttachmentArgs)

            if load_balancer_id is None and not opts.urn:
                raise TypeError("Missing required property 'load_balancer_id'")
            __props__.__dict__["load_balancer_id"] = load_balancer_id
            if log_project is None and not opts.urn:
                raise TypeError("Missing required property 'log_project'")
            __props__.__dict__["log_project"] = log_project
            if log_store is None and not opts.urn:
                raise TypeError("Missing required property 'log_store'")
            __props__.__dict__["log_store"] = log_store
            __props__.__dict__["create_time"] = None
        super(LoadBalancerAccessLogConfigAttachment, __self__).__init__(
            'alicloud:alb/loadBalancerAccessLogConfigAttachment:LoadBalancerAccessLogConfigAttachment',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            load_balancer_id: Optional[pulumi.Input[str]] = None,
            log_project: Optional[pulumi.Input[str]] = None,
            log_store: Optional[pulumi.Input[str]] = None) -> 'LoadBalancerAccessLogConfigAttachment':
        """
        Get an existing LoadBalancerAccessLogConfigAttachment resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] load_balancer_id: The ID of the load balancing instance.
        :param pulumi.Input[str] log_project: The log items shipped by the access log.
        :param pulumi.Input[str] log_store: Logstore for log delivery.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _LoadBalancerAccessLogConfigAttachmentState.__new__(_LoadBalancerAccessLogConfigAttachmentState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["load_balancer_id"] = load_balancer_id
        __props__.__dict__["log_project"] = log_project
        __props__.__dict__["log_store"] = log_store
        return LoadBalancerAccessLogConfigAttachment(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="loadBalancerId")
    def load_balancer_id(self) -> pulumi.Output[str]:
        """
        The ID of the load balancing instance.
        """
        return pulumi.get(self, "load_balancer_id")

    @property
    @pulumi.getter(name="logProject")
    def log_project(self) -> pulumi.Output[str]:
        """
        The log items shipped by the access log.
        """
        return pulumi.get(self, "log_project")

    @property
    @pulumi.getter(name="logStore")
    def log_store(self) -> pulumi.Output[str]:
        """
        Logstore for log delivery.
        """
        return pulumi.get(self, "log_store")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['DataSourceSharedRuleArgs', 'DataSourceSharedRule']

@pulumi.input_type
class DataSourceSharedRuleArgs:
    def __init__(__self__, *,
                 data_source_id: pulumi.Input[int],
                 env_type: pulumi.Input[str],
                 target_project_id: pulumi.Input[int],
                 shared_user: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a DataSourceSharedRule resource.
        :param pulumi.Input[int] data_source_id: The ID of the data source, that is, the unique identifier of the data source.
        :param pulumi.Input[str] env_type: The environment type of the data source shared to the target project, such as Dev (Development Environment) and Prod (production environment).
        :param pulumi.Input[int] target_project_id: The ID of the project to which the data source is shared.
        :param pulumi.Input[str] shared_user: The target user of the data source permission policy, which is null to share to the project.
        """
        pulumi.set(__self__, "data_source_id", data_source_id)
        pulumi.set(__self__, "env_type", env_type)
        pulumi.set(__self__, "target_project_id", target_project_id)
        if shared_user is not None:
            pulumi.set(__self__, "shared_user", shared_user)

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> pulumi.Input[int]:
        """
        The ID of the data source, that is, the unique identifier of the data source.
        """
        return pulumi.get(self, "data_source_id")

    @data_source_id.setter
    def data_source_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "data_source_id", value)

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> pulumi.Input[str]:
        """
        The environment type of the data source shared to the target project, such as Dev (Development Environment) and Prod (production environment).
        """
        return pulumi.get(self, "env_type")

    @env_type.setter
    def env_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "env_type", value)

    @property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> pulumi.Input[int]:
        """
        The ID of the project to which the data source is shared.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: pulumi.Input[int]):
        pulumi.set(self, "target_project_id", value)

    @property
    @pulumi.getter(name="sharedUser")
    def shared_user(self) -> Optional[pulumi.Input[str]]:
        """
        The target user of the data source permission policy, which is null to share to the project.
        """
        return pulumi.get(self, "shared_user")

    @shared_user.setter
    def shared_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shared_user", value)


@pulumi.input_type
class _DataSourceSharedRuleState:
    def __init__(__self__, *,
                 create_time: Optional[pulumi.Input[int]] = None,
                 data_source_id: Optional[pulumi.Input[int]] = None,
                 data_source_shared_rule_id: Optional[pulumi.Input[str]] = None,
                 env_type: Optional[pulumi.Input[str]] = None,
                 shared_user: Optional[pulumi.Input[str]] = None,
                 target_project_id: Optional[pulumi.Input[int]] = None):
        """
        Input properties used for looking up and filtering DataSourceSharedRule resources.
        :param pulumi.Input[int] create_time: The creation time of the data source sharing rule.
        :param pulumi.Input[int] data_source_id: The ID of the data source, that is, the unique identifier of the data source.
        :param pulumi.Input[str] data_source_shared_rule_id: The data source sharing rule ID, that is, the unique identifier of the data source sharing rule.
        :param pulumi.Input[str] env_type: The environment type of the data source shared to the target project, such as Dev (Development Environment) and Prod (production environment).
        :param pulumi.Input[str] shared_user: The target user of the data source permission policy, which is null to share to the project.
        :param pulumi.Input[int] target_project_id: The ID of the project to which the data source is shared.
        """
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if data_source_id is not None:
            pulumi.set(__self__, "data_source_id", data_source_id)
        if data_source_shared_rule_id is not None:
            pulumi.set(__self__, "data_source_shared_rule_id", data_source_shared_rule_id)
        if env_type is not None:
            pulumi.set(__self__, "env_type", env_type)
        if shared_user is not None:
            pulumi.set(__self__, "shared_user", shared_user)
        if target_project_id is not None:
            pulumi.set(__self__, "target_project_id", target_project_id)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[int]]:
        """
        The creation time of the data source sharing rule.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the data source, that is, the unique identifier of the data source.
        """
        return pulumi.get(self, "data_source_id")

    @data_source_id.setter
    def data_source_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "data_source_id", value)

    @property
    @pulumi.getter(name="dataSourceSharedRuleId")
    def data_source_shared_rule_id(self) -> Optional[pulumi.Input[str]]:
        """
        The data source sharing rule ID, that is, the unique identifier of the data source sharing rule.
        """
        return pulumi.get(self, "data_source_shared_rule_id")

    @data_source_shared_rule_id.setter
    def data_source_shared_rule_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "data_source_shared_rule_id", value)

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> Optional[pulumi.Input[str]]:
        """
        The environment type of the data source shared to the target project, such as Dev (Development Environment) and Prod (production environment).
        """
        return pulumi.get(self, "env_type")

    @env_type.setter
    def env_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "env_type", value)

    @property
    @pulumi.getter(name="sharedUser")
    def shared_user(self) -> Optional[pulumi.Input[str]]:
        """
        The target user of the data source permission policy, which is null to share to the project.
        """
        return pulumi.get(self, "shared_user")

    @shared_user.setter
    def shared_user(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "shared_user", value)

    @property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> Optional[pulumi.Input[int]]:
        """
        The ID of the project to which the data source is shared.
        """
        return pulumi.get(self, "target_project_id")

    @target_project_id.setter
    def target_project_id(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "target_project_id", value)


class DataSourceSharedRule(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_source_id: Optional[pulumi.Input[int]] = None,
                 env_type: Optional[pulumi.Input[str]] = None,
                 shared_user: Optional[pulumi.Input[str]] = None,
                 target_project_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        """
        Provides a Data Works Data Source Shared Rule resource.

        Data source sharing rule, which expresses A data source, from space A to space B (A user).

        For information about Data Works Data Source Shared Rule and how to use it, see [What is Data Source Shared Rule](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.237.0.

        ## Import

        Data Works Data Source Shared Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/dataSourceSharedRule:DataSourceSharedRule example <data_source_id>:<data_source_shared_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] data_source_id: The ID of the data source, that is, the unique identifier of the data source.
        :param pulumi.Input[str] env_type: The environment type of the data source shared to the target project, such as Dev (Development Environment) and Prod (production environment).
        :param pulumi.Input[str] shared_user: The target user of the data source permission policy, which is null to share to the project.
        :param pulumi.Input[int] target_project_id: The ID of the project to which the data source is shared.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: DataSourceSharedRuleArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a Data Works Data Source Shared Rule resource.

        Data source sharing rule, which expresses A data source, from space A to space B (A user).

        For information about Data Works Data Source Shared Rule and how to use it, see [What is Data Source Shared Rule](https://www.alibabacloud.com/help/en/).

        > **NOTE:** Available since v1.237.0.

        ## Import

        Data Works Data Source Shared Rule can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:dataworks/dataSourceSharedRule:DataSourceSharedRule example <data_source_id>:<data_source_shared_rule_id>
        ```

        :param str resource_name: The name of the resource.
        :param DataSourceSharedRuleArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(DataSourceSharedRuleArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 data_source_id: Optional[pulumi.Input[int]] = None,
                 env_type: Optional[pulumi.Input[str]] = None,
                 shared_user: Optional[pulumi.Input[str]] = None,
                 target_project_id: Optional[pulumi.Input[int]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = DataSourceSharedRuleArgs.__new__(DataSourceSharedRuleArgs)

            if data_source_id is None and not opts.urn:
                raise TypeError("Missing required property 'data_source_id'")
            __props__.__dict__["data_source_id"] = data_source_id
            if env_type is None and not opts.urn:
                raise TypeError("Missing required property 'env_type'")
            __props__.__dict__["env_type"] = env_type
            __props__.__dict__["shared_user"] = shared_user
            if target_project_id is None and not opts.urn:
                raise TypeError("Missing required property 'target_project_id'")
            __props__.__dict__["target_project_id"] = target_project_id
            __props__.__dict__["create_time"] = None
            __props__.__dict__["data_source_shared_rule_id"] = None
        super(DataSourceSharedRule, __self__).__init__(
            'alicloud:dataworks/dataSourceSharedRule:DataSourceSharedRule',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            create_time: Optional[pulumi.Input[int]] = None,
            data_source_id: Optional[pulumi.Input[int]] = None,
            data_source_shared_rule_id: Optional[pulumi.Input[str]] = None,
            env_type: Optional[pulumi.Input[str]] = None,
            shared_user: Optional[pulumi.Input[str]] = None,
            target_project_id: Optional[pulumi.Input[int]] = None) -> 'DataSourceSharedRule':
        """
        Get an existing DataSourceSharedRule resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] create_time: The creation time of the data source sharing rule.
        :param pulumi.Input[int] data_source_id: The ID of the data source, that is, the unique identifier of the data source.
        :param pulumi.Input[str] data_source_shared_rule_id: The data source sharing rule ID, that is, the unique identifier of the data source sharing rule.
        :param pulumi.Input[str] env_type: The environment type of the data source shared to the target project, such as Dev (Development Environment) and Prod (production environment).
        :param pulumi.Input[str] shared_user: The target user of the data source permission policy, which is null to share to the project.
        :param pulumi.Input[int] target_project_id: The ID of the project to which the data source is shared.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _DataSourceSharedRuleState.__new__(_DataSourceSharedRuleState)

        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["data_source_id"] = data_source_id
        __props__.__dict__["data_source_shared_rule_id"] = data_source_shared_rule_id
        __props__.__dict__["env_type"] = env_type
        __props__.__dict__["shared_user"] = shared_user
        __props__.__dict__["target_project_id"] = target_project_id
        return DataSourceSharedRule(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[int]:
        """
        The creation time of the data source sharing rule.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter(name="dataSourceId")
    def data_source_id(self) -> pulumi.Output[int]:
        """
        The ID of the data source, that is, the unique identifier of the data source.
        """
        return pulumi.get(self, "data_source_id")

    @property
    @pulumi.getter(name="dataSourceSharedRuleId")
    def data_source_shared_rule_id(self) -> pulumi.Output[str]:
        """
        The data source sharing rule ID, that is, the unique identifier of the data source sharing rule.
        """
        return pulumi.get(self, "data_source_shared_rule_id")

    @property
    @pulumi.getter(name="envType")
    def env_type(self) -> pulumi.Output[str]:
        """
        The environment type of the data source shared to the target project, such as Dev (Development Environment) and Prod (production environment).
        """
        return pulumi.get(self, "env_type")

    @property
    @pulumi.getter(name="sharedUser")
    def shared_user(self) -> pulumi.Output[Optional[str]]:
        """
        The target user of the data source permission policy, which is null to share to the project.
        """
        return pulumi.get(self, "shared_user")

    @property
    @pulumi.getter(name="targetProjectId")
    def target_project_id(self) -> pulumi.Output[int]:
        """
        The ID of the project to which the data source is shared.
        """
        return pulumi.get(self, "target_project_id")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = [
    'RecordAuthConfArgs',
    'RecordAuthConfArgsDict',
    'RecordDataArgs',
    'RecordDataArgsDict',
]

MYPY = False

if not MYPY:
    class RecordAuthConfArgsDict(TypedDict):
        access_key: NotRequired[pulumi.Input[str]]
        """
        The access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        """
        auth_type: NotRequired[pulumi.Input[str]]
        """
        The authentication type of the origin server. Different origins support different authentication types. The type of origin refers to the SourceType parameter in this operation. If the type of origin is OSS or S3, you must specify the authentication type of the origin. Valid values:
        """
        region: NotRequired[pulumi.Input[str]]
        """
        The version of the signature algorithm. This parameter is required when the origin type is S3 and AuthType is private. The following two types are supported:
        """
        secret_key: NotRequired[pulumi.Input[str]]
        """
        The secret access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        """
        version: NotRequired[pulumi.Input[str]]
        """
        The region of the origin. If the origin type is S3, you must specify this value. You can get the region information from the official website of S3.
        """
elif False:
    RecordAuthConfArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RecordAuthConfArgs:
    def __init__(__self__, *,
                 access_key: Optional[pulumi.Input[str]] = None,
                 auth_type: Optional[pulumi.Input[str]] = None,
                 region: Optional[pulumi.Input[str]] = None,
                 secret_key: Optional[pulumi.Input[str]] = None,
                 version: Optional[pulumi.Input[str]] = None):
        """
        :param pulumi.Input[str] access_key: The access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        :param pulumi.Input[str] auth_type: The authentication type of the origin server. Different origins support different authentication types. The type of origin refers to the SourceType parameter in this operation. If the type of origin is OSS or S3, you must specify the authentication type of the origin. Valid values:
        :param pulumi.Input[str] region: The version of the signature algorithm. This parameter is required when the origin type is S3 and AuthType is private. The following two types are supported:
        :param pulumi.Input[str] secret_key: The secret access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        :param pulumi.Input[str] version: The region of the origin. If the origin type is S3, you must specify this value. You can get the region information from the official website of S3.
        """
        if access_key is not None:
            pulumi.set(__self__, "access_key", access_key)
        if auth_type is not None:
            pulumi.set(__self__, "auth_type", auth_type)
        if region is not None:
            pulumi.set(__self__, "region", region)
        if secret_key is not None:
            pulumi.set(__self__, "secret_key", secret_key)
        if version is not None:
            pulumi.set(__self__, "version", version)

    @property
    @pulumi.getter(name="accessKey")
    def access_key(self) -> Optional[pulumi.Input[str]]:
        """
        The access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        """
        return pulumi.get(self, "access_key")

    @access_key.setter
    def access_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "access_key", value)

    @property
    @pulumi.getter(name="authType")
    def auth_type(self) -> Optional[pulumi.Input[str]]:
        """
        The authentication type of the origin server. Different origins support different authentication types. The type of origin refers to the SourceType parameter in this operation. If the type of origin is OSS or S3, you must specify the authentication type of the origin. Valid values:
        """
        return pulumi.get(self, "auth_type")

    @auth_type.setter
    def auth_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "auth_type", value)

    @property
    @pulumi.getter
    def region(self) -> Optional[pulumi.Input[str]]:
        """
        The version of the signature algorithm. This parameter is required when the origin type is S3 and AuthType is private. The following two types are supported:
        """
        return pulumi.get(self, "region")

    @region.setter
    def region(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "region", value)

    @property
    @pulumi.getter(name="secretKey")
    def secret_key(self) -> Optional[pulumi.Input[str]]:
        """
        The secret access key of the account to which the origin server belongs. This parameter is required when the SourceType is OSS, and AuthType is private_same_account, or when the SourceType is S3 and AuthType is private.
        """
        return pulumi.get(self, "secret_key")

    @secret_key.setter
    def secret_key(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "secret_key", value)

    @property
    @pulumi.getter
    def version(self) -> Optional[pulumi.Input[str]]:
        """
        The region of the origin. If the origin type is S3, you must specify this value. You can get the region information from the official website of S3.
        """
        return pulumi.get(self, "version")

    @version.setter
    def version(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version", value)


if not MYPY:
    class RecordDataArgsDict(TypedDict):
        algorithm: NotRequired[pulumi.Input[int]]
        """
        The encryption algorithm used for the record, specified within the range from 0 to 255. This parameter is required when you add CERT or SSHFP records.
        """
        certificate: NotRequired[pulumi.Input[str]]
        """
        The public key of the certificate. This parameter is required when you add CERT, SMIMEA, or TLSA records.
        """
        fingerprint: NotRequired[pulumi.Input[str]]
        """
        The public key fingerprint of the record. This parameter is required when you add a SSHFP record.
        """
        flag: NotRequired[pulumi.Input[int]]
        """
        The flag bit of the record. The Flag for a CAA record indicates its priority and how it is processed, specified within the range of 0 to 255. This parameter is required when you add a CAA record.
        """
        key_tag: NotRequired[pulumi.Input[int]]
        """
        The public key identification for the record, specified within the range of 0 to 65,535. This parameter is required when you add a CAA record.
        """
        matching_type: NotRequired[pulumi.Input[int]]
        """
        The algorithm policy used to match or validate the certificate, specified within the range 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        port: NotRequired[pulumi.Input[int]]
        """
        The port of the record, specified within the range of 0 to 65,535. This parameter is required when you add an SRV record.
        """
        priority: NotRequired[pulumi.Input[int]]
        """
        The priority of the record, specified within the range of 0 to 65,535. A smaller value indicates a higher priority. This parameter is required when you add MX, SRV, and URI records.
        """
        selector: NotRequired[pulumi.Input[int]]
        """
        The type of certificate or public key, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        tag: NotRequired[pulumi.Input[str]]
        """
        The label of the record. The Tag of a CAA record indicate its specific type and usage. This parameter is required when you add a CAA record.
        """
        type: NotRequired[pulumi.Input[int]]
        """
        The certificate type of the record (in CERT records), or the public key type (in SSHFP records). This parameter is required when you add CERT or SSHFP records.
        """
        usage: NotRequired[pulumi.Input[int]]
        """
        The usage identifier of the record, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        value: NotRequired[pulumi.Input[str]]
        """
        The record value or part of the record content. This parameter is required when you add A/AAAA, CNAME, NS, MX, TXT, CAA, SRV, and URI records. It has different meanings based on different types of records:

        - **A/AAAA**: the IP address(es). Separate multiple IPs with commas (,). You must have at least one IPv4 address.
        - `CNAME`: the target domain name.
        - `NS`: the name servers for the domain name.
        - `MX`: a valid domain name of the target mail server.
        - `TXT`: a valid text string.
        - `CAA`: a valid domain name of the certificate authority.
        - `SRV`: a valid domain name of the target host.
        - `URI`: a valid URI string.
        """
        weight: NotRequired[pulumi.Input[int]]
        """
        The weight of the record, specified within the range of 0 to 65,535. This parameter is required when you add SRV or URI records.
        """
elif False:
    RecordDataArgsDict: TypeAlias = Mapping[str, Any]

@pulumi.input_type
class RecordDataArgs:
    def __init__(__self__, *,
                 algorithm: Optional[pulumi.Input[int]] = None,
                 certificate: Optional[pulumi.Input[str]] = None,
                 fingerprint: Optional[pulumi.Input[str]] = None,
                 flag: Optional[pulumi.Input[int]] = None,
                 key_tag: Optional[pulumi.Input[int]] = None,
                 matching_type: Optional[pulumi.Input[int]] = None,
                 port: Optional[pulumi.Input[int]] = None,
                 priority: Optional[pulumi.Input[int]] = None,
                 selector: Optional[pulumi.Input[int]] = None,
                 tag: Optional[pulumi.Input[str]] = None,
                 type: Optional[pulumi.Input[int]] = None,
                 usage: Optional[pulumi.Input[int]] = None,
                 value: Optional[pulumi.Input[str]] = None,
                 weight: Optional[pulumi.Input[int]] = None):
        """
        :param pulumi.Input[int] algorithm: The encryption algorithm used for the record, specified within the range from 0 to 255. This parameter is required when you add CERT or SSHFP records.
        :param pulumi.Input[str] certificate: The public key of the certificate. This parameter is required when you add CERT, SMIMEA, or TLSA records.
        :param pulumi.Input[str] fingerprint: The public key fingerprint of the record. This parameter is required when you add a SSHFP record.
        :param pulumi.Input[int] flag: The flag bit of the record. The Flag for a CAA record indicates its priority and how it is processed, specified within the range of 0 to 255. This parameter is required when you add a CAA record.
        :param pulumi.Input[int] key_tag: The public key identification for the record, specified within the range of 0 to 65,535. This parameter is required when you add a CAA record.
        :param pulumi.Input[int] matching_type: The algorithm policy used to match or validate the certificate, specified within the range 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        :param pulumi.Input[int] port: The port of the record, specified within the range of 0 to 65,535. This parameter is required when you add an SRV record.
        :param pulumi.Input[int] priority: The priority of the record, specified within the range of 0 to 65,535. A smaller value indicates a higher priority. This parameter is required when you add MX, SRV, and URI records.
        :param pulumi.Input[int] selector: The type of certificate or public key, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        :param pulumi.Input[str] tag: The label of the record. The Tag of a CAA record indicate its specific type and usage. This parameter is required when you add a CAA record.
        :param pulumi.Input[int] type: The certificate type of the record (in CERT records), or the public key type (in SSHFP records). This parameter is required when you add CERT or SSHFP records.
        :param pulumi.Input[int] usage: The usage identifier of the record, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        :param pulumi.Input[str] value: The record value or part of the record content. This parameter is required when you add A/AAAA, CNAME, NS, MX, TXT, CAA, SRV, and URI records. It has different meanings based on different types of records:
               
               - **A/AAAA**: the IP address(es). Separate multiple IPs with commas (,). You must have at least one IPv4 address.
               - `CNAME`: the target domain name.
               - `NS`: the name servers for the domain name.
               - `MX`: a valid domain name of the target mail server.
               - `TXT`: a valid text string.
               - `CAA`: a valid domain name of the certificate authority.
               - `SRV`: a valid domain name of the target host.
               - `URI`: a valid URI string.
        :param pulumi.Input[int] weight: The weight of the record, specified within the range of 0 to 65,535. This parameter is required when you add SRV or URI records.
        """
        if algorithm is not None:
            pulumi.set(__self__, "algorithm", algorithm)
        if certificate is not None:
            pulumi.set(__self__, "certificate", certificate)
        if fingerprint is not None:
            pulumi.set(__self__, "fingerprint", fingerprint)
        if flag is not None:
            pulumi.set(__self__, "flag", flag)
        if key_tag is not None:
            pulumi.set(__self__, "key_tag", key_tag)
        if matching_type is not None:
            pulumi.set(__self__, "matching_type", matching_type)
        if port is not None:
            pulumi.set(__self__, "port", port)
        if priority is not None:
            pulumi.set(__self__, "priority", priority)
        if selector is not None:
            pulumi.set(__self__, "selector", selector)
        if tag is not None:
            pulumi.set(__self__, "tag", tag)
        if type is not None:
            pulumi.set(__self__, "type", type)
        if usage is not None:
            pulumi.set(__self__, "usage", usage)
        if value is not None:
            pulumi.set(__self__, "value", value)
        if weight is not None:
            pulumi.set(__self__, "weight", weight)

    @property
    @pulumi.getter
    def algorithm(self) -> Optional[pulumi.Input[int]]:
        """
        The encryption algorithm used for the record, specified within the range from 0 to 255. This parameter is required when you add CERT or SSHFP records.
        """
        return pulumi.get(self, "algorithm")

    @algorithm.setter
    def algorithm(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "algorithm", value)

    @property
    @pulumi.getter
    def certificate(self) -> Optional[pulumi.Input[str]]:
        """
        The public key of the certificate. This parameter is required when you add CERT, SMIMEA, or TLSA records.
        """
        return pulumi.get(self, "certificate")

    @certificate.setter
    def certificate(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "certificate", value)

    @property
    @pulumi.getter
    def fingerprint(self) -> Optional[pulumi.Input[str]]:
        """
        The public key fingerprint of the record. This parameter is required when you add a SSHFP record.
        """
        return pulumi.get(self, "fingerprint")

    @fingerprint.setter
    def fingerprint(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "fingerprint", value)

    @property
    @pulumi.getter
    def flag(self) -> Optional[pulumi.Input[int]]:
        """
        The flag bit of the record. The Flag for a CAA record indicates its priority and how it is processed, specified within the range of 0 to 255. This parameter is required when you add a CAA record.
        """
        return pulumi.get(self, "flag")

    @flag.setter
    def flag(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "flag", value)

    @property
    @pulumi.getter(name="keyTag")
    def key_tag(self) -> Optional[pulumi.Input[int]]:
        """
        The public key identification for the record, specified within the range of 0 to 65,535. This parameter is required when you add a CAA record.
        """
        return pulumi.get(self, "key_tag")

    @key_tag.setter
    def key_tag(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "key_tag", value)

    @property
    @pulumi.getter(name="matchingType")
    def matching_type(self) -> Optional[pulumi.Input[int]]:
        """
        The algorithm policy used to match or validate the certificate, specified within the range 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        return pulumi.get(self, "matching_type")

    @matching_type.setter
    def matching_type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "matching_type", value)

    @property
    @pulumi.getter
    def port(self) -> Optional[pulumi.Input[int]]:
        """
        The port of the record, specified within the range of 0 to 65,535. This parameter is required when you add an SRV record.
        """
        return pulumi.get(self, "port")

    @port.setter
    def port(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "port", value)

    @property
    @pulumi.getter
    def priority(self) -> Optional[pulumi.Input[int]]:
        """
        The priority of the record, specified within the range of 0 to 65,535. A smaller value indicates a higher priority. This parameter is required when you add MX, SRV, and URI records.
        """
        return pulumi.get(self, "priority")

    @priority.setter
    def priority(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "priority", value)

    @property
    @pulumi.getter
    def selector(self) -> Optional[pulumi.Input[int]]:
        """
        The type of certificate or public key, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        return pulumi.get(self, "selector")

    @selector.setter
    def selector(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "selector", value)

    @property
    @pulumi.getter
    def tag(self) -> Optional[pulumi.Input[str]]:
        """
        The label of the record. The Tag of a CAA record indicate its specific type and usage. This parameter is required when you add a CAA record.
        """
        return pulumi.get(self, "tag")

    @tag.setter
    def tag(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "tag", value)

    @property
    @pulumi.getter
    def type(self) -> Optional[pulumi.Input[int]]:
        """
        The certificate type of the record (in CERT records), or the public key type (in SSHFP records). This parameter is required when you add CERT or SSHFP records.
        """
        return pulumi.get(self, "type")

    @type.setter
    def type(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "type", value)

    @property
    @pulumi.getter
    def usage(self) -> Optional[pulumi.Input[int]]:
        """
        The usage identifier of the record, specified within the range of 0 to 255. This parameter is required when you add SMIMEA or TLSA records.
        """
        return pulumi.get(self, "usage")

    @usage.setter
    def usage(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "usage", value)

    @property
    @pulumi.getter
    def value(self) -> Optional[pulumi.Input[str]]:
        """
        The record value or part of the record content. This parameter is required when you add A/AAAA, CNAME, NS, MX, TXT, CAA, SRV, and URI records. It has different meanings based on different types of records:

        - **A/AAAA**: the IP address(es). Separate multiple IPs with commas (,). You must have at least one IPv4 address.
        - `CNAME`: the target domain name.
        - `NS`: the name servers for the domain name.
        - `MX`: a valid domain name of the target mail server.
        - `TXT`: a valid text string.
        - `CAA`: a valid domain name of the certificate authority.
        - `SRV`: a valid domain name of the target host.
        - `URI`: a valid URI string.
        """
        return pulumi.get(self, "value")

    @value.setter
    def value(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "value", value)

    @property
    @pulumi.getter
    def weight(self) -> Optional[pulumi.Input[int]]:
        """
        The weight of the record, specified within the range of 0 to 65,535. This parameter is required when you add SRV or URI records.
        """
        return pulumi.get(self, "weight")

    @weight.setter
    def weight(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "weight", value)


